@@ -10,9 +10,9 @@
 
 __author__ = """Stephen Wasilewski"""
 __email__ = 'stephanwaz@gmail.com'
-__version__ = '1.1.2'
+__version__ = '1.2.0'
 __all__ = ['crenderer', 'evaluate', 'formatter', 'lightpoint', 'mapper',
-           'renderer', 'sampler', 'scene', 'sky', 'io', 'plot', 'translate']
+           'renderer', 'sampler', 'scene', 'sky', 'io', 'translate']
 
 
 def set_raypath(basefile=__file__, subd="cal"):
