@@ -16,9 +16,6 @@ class Formatter(object):
     #: line comment character
     comment = "#"
 
-    #: arguments for direct trace
-    direct_args = ""
-
     #: extension for renderer scene file
     scene_ext = ""
 
@@ -53,16 +50,6 @@ class Formatter(object):
         """assemble sun definition"""
         pass
 
-    @staticmethod
-    def get_contribution_args(render_args, side, name):
-        """prepare arguments for contribution based simulation"""
-        pass
-
-    @staticmethod
-    def get_standard_args(render_args, ambfile=None):
-        """prepare arguments for standard simulations"""
-        pass
-
     @staticmethod
     def extract_sources(srcdef, accuracy):
         """scan scene file for sun source definitions"""
