@@ -11,15 +11,11 @@
 from datetime import datetime, timezone
 import shlex
 import os
-import sys
 from subprocess import Popen, PIPE
-from scipy.ndimage.filters import uniform_filter
 
 import numpy as np
 
 import raytraverse
-from raytraverse import translate
-from raytraverse.mapper import ViewMapper
 from raytraverse.crenderer import cRtrace
 
 
@@ -214,24 +210,14 @@ def carray2hdr(ar, imgf, header=None):
     return _array2hdr(ar.T[-1::-1, -1::-1, :], imgf, header, pval)
 
 
-def uvarray2hdr(uvarray, imgf, header=None):
-    res = uvarray.shape[0]
-    vm = ViewMapper(viewangle=180)
-    pixelxyz = vm.pixelrays(res)
-    uv = vm.xyz2uv(pixelxyz.reshape(-1, 3))
-    mask = vm.in_view(pixelxyz, indices=False)
-    ij = translate.uv2ij(uv[mask], res)
-    img = np.zeros(res*res)
-    img[mask] = uvarray[ij[:, 0], ij[-1:None:-1, 1]]
-    array2hdr(img.reshape(res, res), imgf, header)
-
-
-def hdr2array(imgf):
+def hdr2array(imgf, stdin=None):
     """read np.array from hdr image
 
     Parameters
     ----------
     imgf: file path of image
+    stdin:
+        passed to Popen (imgf should be "")
 
     Returns
     -------
@@ -239,7 +225,7 @@ def hdr2array(imgf):
 
     """
     pval = f'pvalue -b -h -df -o {imgf}'
-    p = Popen(pval.split(), stdout=PIPE)
+    p = Popen(shlex.split(pval), stdin=stdin, stdout=PIPE)
     shape = p.stdout.readline().strip().split()
     shape = (int(shape[-3]), int(shape[-1]))
     return bytes2np(p.stdout.read(), shape)[-1::-1, -1::-1]
@@ -275,34 +261,3 @@ def rgbe2lum(rgbe):
     rgb = np.where(rgbe[:, 0:3] == 0, 0, (rgbe[:, 0:3] + 0.5) * v)
     # luminance = 179 * (0.265*R + 0.670*G + 0.065*B)
     return rgb2lum(rgb)
-
-
-def add_vecs_to_img(vm, img, v, channels=(1, 0, 0), grow=0):
-    res = img.shape[-1]
-    if vm.viewangle == 360:
-        reverse = vm.degrees(v) > 90
-        pa = vm.ivm.ray2pixel(v[reverse], res)
-        pa[:, 0] += res
-        pb = vm.ray2pixel(v[np.logical_not(reverse)], res)
-        xp = np.concatenate((pa[:, 0], pb[:, 0]))
-        yp = np.concatenate((pa[:, 1], pb[:, 1]))
-    else:
-        pb = vm.ray2pixel(v, res)
-        xp = pb[:, 0]
-        yp = pb[:, 1]
-    r = int(grow*2 + 1)
-    if len(img.shape) == 2:
-        try:
-            channel = channels[0]
-        except TypeError:
-            channel = channels
-        img[xp, yp] = channel
-        if grow > 0:
-            img = uniform_filter(img*r**2, r)
-    else:
-        for i in range(img.shape[0]):
-            if channels[i] is not None:
-                img[i, xp, yp] = channels[i]
-        if grow > 0:
-            img = uniform_filter(img*r**2, (1, r, r))
-    return img
