@@ -13,7 +13,7 @@ from raytraverse import io, translate
 from raytraverse.evaluate import MetricSet
 from raytraverse.renderer import Rtrace, Rcontrib
 from raytraverse.scene import Scene
-from raytraverse.sampler import SkySampler, SunSampler, SunViewSampler
+from raytraverse.sampler import SkySamplerPt, SunSamplerPt, SunSamplerPtView
 from raytraverse.mapper import ViewMapper
 
 
@@ -35,7 +35,7 @@ def test_skysample(tmpdir):
 
     def img_illum(lf0, vm0, sbin):
         outf = lf0.direct_view(res=512, srcidx=sbin, showsample=False,
-                               scalefactor=1)
+                               scalefactor=1, vm=vm0)
         hdr = io.hdr2array(outf)
         vecs = vm0.pixelrays(512)
         pxs = vm0.pixels(512).reshape(-1, 2)
@@ -44,15 +44,15 @@ def test_skysample(tmpdir):
 
         coefs = np.zeros(325)
         coefs[sbin] = 1
-        illumm0 = MetricSet(vm, *lf.get_applied_rays(coefs, vm), ["illum"])()[0]
+        illumm0 = MetricSet(*lf.evaluate(coefs, vm0), vm0, ["illum"])()[0]
 
         return np.sum(hdr.flatten()*omega*cost)*179, illumm0
 
     scene = Scene('skysample', "box.rad", frozen=False)
     rcontrib = Rcontrib('-ab 1 -ad 10000 -c 1 -lw 1e-5', scene.scene)
-    sampler = SkySampler(scene, rcontrib, fdres=7)
+    sampler = SkySamplerPt(scene, rcontrib, fdres=7)
     vm = ViewMapper((0, 1, 0), viewangle=180)
-    lf = sampler.run((1.5, 1.5, 1.5), 0, vm)
+    lf = sampler.run((1.5, 1.5, 1.5), 0)
     illum, illumm = img_illum(lf, vm, 176)
     assert np.isclose(illum, illumm, atol=.2, rtol=.1)
     illum2, illumm2 = img_illum(lf, vm, 158)
@@ -61,9 +61,9 @@ def test_skysample(tmpdir):
     illum, illumm = img_illum(lf, vm, 174)
     assert np.isclose(illum, illumm, atol=.2, rtol=.1)
     assert np.isclose(np.average([illum, illumm]), 0.169, atol=.03, rtol=.2)
-    fmetric = MetricSet(vm, *lf.get_applied_rays(np.ones(325), vm), ["illum", "density"])()
+    fmetric = MetricSet(*lf.evaluate(np.ones(325), vm), vm, ["illum", "density"])()
     assert np.isclose(fmetric[0], 352.7, atol=1, rtol=.01)
-    assert np.isclose(fmetric[1], 612, atol=30)
+    assert np.isclose(fmetric[1], 570, atol=30)
     Rcontrib.reset()
     Rcontrib._pyinstance = None
 
@@ -77,19 +77,20 @@ def test_sunsample(tmpdir):
         pxs = vm0.pixels(512).reshape(-1, 2)
         omega = vm0.pixel2omega(pxs, 512)
         cost = vm0.ctheta(vecs)
-        illumm0 = MetricSet(vm, *lf.get_applied_rays(285.32, vm), ["illum"])()[0]
+        illumm0 = MetricSet(*lf.evaluate(285.32, vm), vm, ["illum"])()[0]
 
         return np.sum(hdr.flatten()*omega*cost)*179, illumm0
 
     scene = Scene('skysample', "box.rad", frozen=False)
-    sun = translate.skybin2xyz([174], 18)[0]
     rtrace = Rtrace(scene=scene.scene, direct=True)
-    sampler = SunSampler(scene, rtrace, sun, 174)
-    vm = ViewMapper((0, 1, 0), viewangle=180)
-    lf = sampler.run((1.5, 1.5, 1.5), 0, vm)
-    illum, illumm = img_illum(lf, vm)
-    assert np.isclose(illum, illumm, atol=.01, rtol=.05)
-    assert np.isclose(np.average([illum, illumm]), 0.169, atol=.01, rtol=.01)
+    for sunb, ref in zip([174, 176], [0.169, 2.86]):
+        sun = translate.skybin2xyz([sunb], 18)[0]
+        sampler = SunSamplerPt(scene, rtrace, sun, sunb)
+        vm = ViewMapper((0, 1, 0), viewangle=180)
+        lf = sampler.run((1.5, 1.5, 1.5), 0, vm)
+        illum, illumm = img_illum(lf, vm)
+        assert np.isclose(illum, illumm, atol=.01, rtol=.05)
+        assert np.isclose(np.average([illum, illumm]), ref, atol=.01, rtol=.01)
     sampler.engine.reset()
 
 
@@ -97,7 +98,7 @@ def test_sunviewsample(tmpdir):
     scene = Scene('skysample', "box.rad", frozen=False)
     sun = translate.skybin2xyz([176], 18)[0]
     rtrace = Rtrace(scene=scene.scene, direct=True)
-    sampler = SunViewSampler(scene, rtrace, sun, 176)
+    sampler = SunSamplerPtView(scene, rtrace, sun, 176)
     lf = sampler.run((1.5, 1.5, 1.79), 0, plotp=False)
     lf2 = sampler.run((1.5, 1.5, 1.5), 1, plotp=False)
     assert np.allclose([lf.lum, lf2.lum], 1.0)
